@@ -1,5 +1,9 @@
-from typing import Union, Optional
+import imp
+from json import load
+import os
 
+from dotenv import load_dotenv
+from typing import Type, Union, Optional
 from disnake import (
     ButtonStyle, 
     Embed, 
@@ -15,6 +19,21 @@ from disnake.ext.commands import Context, Bot
 
 newline = '\n'
 
+class InvalidEnv(Exception):
+    """
+    """
+
+try:
+    load_dotenv()
+    os.environ['EMBED_COLOR']
+except KeyError:
+    with open('./.env', 'a') as env:
+        env.write("\n#disnake-debug\nEMBED_COLOR = 0x0000ff")
+try:
+    EMBED_COLOR = hex(int(os.environ['EMBED_COLOR'], 16))
+except TypeError:
+    raise InvalidEnv("EMBED_COLOR must start with 0x and be hex")
+
 def get_bot_message(ctx: Context) -> Message:
     return ctx.bot._bot_messages[ctx.message.id]
 
@@ -123,10 +142,10 @@ class EmbedFactory:
         path: str = None, 
         description: str = None,
         markdown: str = 'yaml',
-    ):
+    ) -> Embed:
         return Embed(
             title=title,
-            colour=0x0000ff,
+            colour=EMBED_COLOR,
             description=f"```yaml\nCurrent path: /{path or ''}```{'```' + markdown + newline + description + '```' if description else ''}",
             timestamp=ctx.message.created_at
         ).set_author(
@@ -136,6 +155,20 @@ class EmbedFactory:
             text=f"Bot ping: {ctx.bot.latency * 1000:.0f} || Uptime: {ctx.bot._get_uptime()}"
         )
 
+    @staticmethod
+    def check_fail(
+        ctx: Context,
+        description: str,
+    ) -> Embed:
+        return Embed(
+            title="Uh oh",
+            description=f"One of my owners has `blacklisted` {description} from using this command.",
+            colour=EMBED_COLOR,
+        ).set_author(
+            name=ctx.author.name,
+            icon_url=ctx.author.avatar.url      
+        )
+
 class MainMenu(Button):
     def __init__(self, ctx: Context):
         super().__init__(
@@ -146,7 +179,7 @@ class MainMenu(Button):
         self.bot_message = get_bot_message(ctx)
 
     async def callback(self, interaction: MessageInteraction):
-        from .exts import DebugView
+        from . import DebugView
 
         embed = EmbedFactory.static_embed(self.ctx, "Debug Controls")
 
